@@ -9,8 +9,6 @@
 
 #include <QObject>
 
-#include <KSharedConfig>
-
 #include <BluezQt/Types>
 
 class KFilePlacesModel;
@@ -50,5 +48,4 @@ private:
     BluezQt::Manager *m_manager;
     bool m_isParentValid;
     KFilePlacesModel *m_places = nullptr;
-    KSharedConfig::Ptr m_config;
 };
